@@ -64,13 +64,15 @@ if (fritools::get_run_r_tests()) {
                   file_name  <- file.path(system.file("files",
                                                       package = "document"),
                                           "produce_warning.R")
-                  if (! probably_winbuilder())
-                      expect_warning(
-                                     document(file_name, check_package = TRUE,
-                                              runit = TRUE,
-                                              stop_on_check_not_passing = TRUE,
-                                              check_as_cran = FALSE)
-                                     )
-    }
-    )
+                  if (! probably_winbuilder()) {
+                      result <- document(file_name, check_package = TRUE,
+                                         runit = TRUE,
+                                         stop_on_check_not_passing = TRUE,
+                                         check_as_cran = FALSE)
+                      expectation <- c(errors = FALSE, warnings = TRUE,
+                                       notes = FALSE)
+                      testthat::expect_identical(checks(result$check_result),
+                                                 expectation)
+                  }
+    })
 }
